@@ -7,9 +7,6 @@ from pyramid.response import Response
 from pyramid.view import view_config
 from pyramid.exceptions import NotFound
 
-# pyramid_debugtoolbar
-from pyramid_debugtoolbar.utils import find_request_history
-
 # lcoal
 from .utils import get_sqlalchemy_panel
 
@@ -20,7 +17,7 @@ from .utils import get_sqlalchemy_panel
 @view_config(route_name='debugtoolbar.api_sqlalchemy.queries.csv')
 def queries_api_csv(request):
 
-    history = find_request_history(request)
+    history = request.pdtb_history
     try:
         last_request_pair = history.last(1)[0]
     except IndexError:
